@@ -1,8 +1,6 @@
 use swc_ecma_parser::Syntax;
-use swc_ecma_transforms_compat::es2015::for_of::for_of;
-use swc_ecma_transforms_compat::es2015::for_of::Config;
-use swc_ecma_transforms_testing::test;
-use swc_ecma_transforms_testing::test_exec;
+use swc_ecma_transforms_compat::es2015::for_of::{for_of, Config};
+use swc_ecma_transforms_testing::{test, test_exec};
 
 fn syntax() -> Syntax {
     Default::default()
